@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import Any, List, Tuple
 
 import os
 from glob import glob
@@ -22,7 +22,7 @@ def resolve_paths(
 def generate_path_pattern(
     path_prefix: str,
     path_pattern: str,
-    *args,
+    *args: Any,
 ) -> str:
     full_pattern = path_prefix + path_pattern
 
